Lyrid
==============

[![PyPi Version](https://img.shields.io/pypi/v/lyrid)](https://pypi.org/project/lyrid/)
[![Supported Python Versions](https://img.shields.io/pypi/pyversions/lyrid.svg)](https://pypi.org/project/lyrid/)
[![License](https://img.shields.io/github/license/ssripilaipong/lyrid)](https://github.com/SSripilaipong/lyrid/blob/master/LICENSE.md)

# Overview

An actor model framework that simplifies concurrent system while support real parallelism.
<br>

No thread/process/async/await, just actor. Implemented in pure Python.'

# Requirements

- Python 3.8+
- Works on Linux, Windows, macOS, BSD

# Installation

using pip:

```
pip install lyrid
```

# Documentation

[Github Wiki](https://github.com/SSripilaipong/lyrid/wiki)
